@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2021 Pier Carlo Chiodi
+# Copyright (C) 2017-2022 Pier Carlo Chiodi
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -83,9 +83,14 @@ class ConfigBuilder(object):
         msg = "Compatibility issue ID '{}'. {}".format(issue_id, text)
         if issue_id in self.ignore_errors or "*" in self.ignore_errors:
             logging.warning(
-                "{} - Ignored".format(msg)
+                "{} - Ignored via --ignore-issues {}".format(msg, issue_id)
             )
             return True
+
+        msg += (
+            " - This issue can be acknowledged and ignored via the CLI option "
+            "--ignore-issues {}".format(issue_id)
+        )
         logging.error(msg)
         return False
 
@@ -126,6 +131,7 @@ class ConfigBuilder(object):
                  cache_dir=None, cache_expiry=CachedObject.DEFAULT_EXPIRY,
                  bgpq3_path="bgpq4", bgpq3_host=IRRDBInfo.BGPQ3_DEFAULT_HOST,
                  bgpq3_sources=IRRDBInfo.BGPQ3_DEFAULT_SOURCES,
+                 bgpq3_timeout=IRRDBInfo.BGPQ3_DEFAULT_TIMEOUT,
                  rtt_getter_path=None, threads=4,
                  ip_ver=None, perform_graceful_shutdown=False,
                  ignore_errors=[], live_tests=False,
@@ -293,8 +299,11 @@ class ConfigBuilder(object):
 
                 - *bgpq3_path* program's configuration file option.
 
-            bgpq3_host (str): the host that will be queried by bgpq3/bgpq4; this
-                will be used to set the *-h* argument of the program.
+            bgpq3_host (str): the host(s) that will be queried by bgpq3/bgpq4; this
+                will be used to set the *-h* argument of the program. Multiple hosts
+                can be passed using a comma-delimited string, in which case they
+                will be used sequentially in case of failures of the IRR queries or
+                timeouts.
 
                 Same of:
 
@@ -308,6 +317,12 @@ class ConfigBuilder(object):
 
                 - *bgpq3_sources* program's configuration file option.
 
+            bgpq3_timeout (int): timeout for the bgpq4/bgpq3 queries (in seconds).
+
+                Same of:
+
+                - *bgpq3_timeout* program's configuration file option.
+
             rtt_getter_path (str): path to the program that is executed to
                 determine the RTT of a peer.
                 Syntax and details can be found at the following URL:
@@ -354,6 +369,7 @@ class ConfigBuilder(object):
         self.bgpq3_path = bgpq3_path
         self.bgpq3_host = bgpq3_host
         self.bgpq3_sources = bgpq3_sources
+        self.bgpq3_timeout = bgpq3_timeout
 
         self.rtt_getter_path = rtt_getter_path
 
@@ -730,7 +746,7 @@ class BIRDConfigBuilder(ConfigBuilder):
     IGNORABLE_ISSUES = ["max_prefix_count_rejected_routes"]
 
     AVAILABLE_VERSION = ["1.6.3", "1.6.4", "1.6.6", "1.6.7", "1.6.8",
-                         "2.0.7", "2.0.7+b962967e", "2.0.8"]
+                         "2.0.7", "2.0.7+b962967e", "2.0.8", "2.0.9"]
     DEFAULT_VERSION = "1.6.8"
 
     def validate_bgpspeaker_specific_configuration(self):
@@ -864,7 +880,7 @@ class OpenBGPDConfigBuilder(ConfigBuilder):
     LOCAL_FILES_BASE_DIR = "/etc/bgpd"
 
     AVAILABLE_VERSION = ["6.0", "6.1", "6.2", "6.3", "6.4", "6.5", "6.6", "6.7",
-                         "6.8", "6.9", "7.0", "7.1"]
+                         "6.8", "6.9", "7.0", "7.1", "7.2"]
     DEFAULT_VERSION = AVAILABLE_VERSION[-1]
 
     IGNORABLE_ISSUES = ["path_hiding", "transit_free_action",
@@ -933,8 +949,7 @@ class OpenBGPDConfigBuilder(ConfigBuilder):
 
         reject_policy = self.cfg_general["filtering"]["reject_policy"]["policy"]
         if reject_policy == "tag_and_reject":
-            res = False
-            logging.error(
+            raise BuilderError(
                 "For OpenBGP, 'reject_policy' can't be set to "
                 "'tag_and_reject'."
             )
@@ -1111,15 +1126,16 @@ class OpenBGPDConfigBuilder(ConfigBuilder):
             self.cfg_general.check_overlapping_communities(
                 allow_private_asns=False)
         except ConfigError as e:
-            res = False
-            logging.error("{}OpenBGPD doesn't allow to delete BGP "
-                          "communities using ranges of values, but only "
-                          "using the wildcard ('*'), so also "
-                          "outbound communities whose last part contain "
-                          "private ASNs collide with inbound communities "
-                          "that use the 'peer_as' macro.".format(
-                              str(e) + " " if str(e) else ""
-                            ))
+            raise BuilderError(
+                "{}OpenBGPD doesn't allow to delete BGP "
+                "communities using ranges of values, but only "
+                "using the wildcard ('*'), so also "
+                "outbound communities whose last part contain "
+                "private ASNs collide with inbound communities "
+                "that use the 'peer_as' macro.".format(
+                    str(e) + " " if str(e) else ""
+                )
+            )
 
         if (self.cfg_general["graceful_shutdown"]["enabled"] or \
             self.perform_graceful_shutdown) and \
